Skip to contents

This function provides help on how to use the leo.table1 functions and basic background knowledge.

Usage

leo.table1.help()

Note

If you encounter a warning about an unknown RStudio theme when using cli functions, you can suppress it by setting:

options(cli.ignore_unknown_rstudio_theme = TRUE)

This option should be set in your R session to avoid the warning.