Check DNAnexus Job Status & Dashboard
dx_status.RdChecks the status of a specific job or displays a dashboard of recent jobs.
Arguments
- all_projects
Logical. If TRUE, shows jobs from all projects in the account (account-wide). Default is FALSE (only current project).
- job_id
Optional. A string containing the job ID (e.g., "job-Gk2...") or a list returned by
dx_extract. If provided,all_projectsis ignored.- limit
Numeric. Number of recent jobs to show in the dashboard (default: 3).
Value
The state of the job as a string (if job_id provided) or a data frame
of recent jobs (if job_id is NULL), invisibly.