Step 1: Check Normality for Variables
leo.table1.step1.RdThis function checks the normality of each variable in the dataset and returns a summary.
Usage
leo.table1.step1(df, id_to_exclude = c("eid", "iri_time"), num_var = NULL)
leo.table1.step1.RdThis function checks the normality of each variable in the dataset and returns a summary.
leo.table1.step1(df, id_to_exclude = c("eid", "iri_time"), num_var = NULL)